::: {#navbar .navbar .navbar-default .navbar-fixed-top role="navigation"}
::: {.container}
::: {.navbar-header}
[]{.icon-bar} []{.icon-bar} []{.icon-bar}

<div>

[![](../_static/img/RAIcon.png)](/runestone/default/user/login){.brand-logo}
[fopp](../index.html){#rs-book-toc-link .navbar-brand}

</div>
:::

::: {.navbar-collapse .collapse .navbar-ex1-collapse}
-   
-   []{#ad_warning}
-   []{#browsing_warning}
-   
-   [*[Search]{.visuallyhidden
    aria-label="Search"}*](#){.dropdown-toggle}
    -   [Table of Contents](../index.html)

    -   [Book Index](../genindex.html)

    -   

    -   ::: {.input-group}
        :::
-   
-   [*[User]{.visuallyhidden aria-label="User"}*](#){.dropdown-toggle}
    -   []{.loggedinuser}

    -   

    -   [Course Home](/ns/course/index)

    -   [Assignments](/assignment/student/chooseAssignment)

    -   [Practice](/runestone/assignments/practice)

    -   [[Peer Instruction
        (Instructor)](/runestone/peer/instructor.html)]{#inst_peer_link}

    -   [Peer Instruction (Student)](/runestone/peer/student.html)

    -   

    -   [Change Course](/runestone/default/courses)

    -   

    -   [[Instructor\'s
        Page](/runestone/admin/index)]{#ip_dropdown_link}

    -   [Progress Page](/runestone/dashboard/studentreport)

    -   

    -   [Edit Profile](/runestone/default/user/profile){#profilelink}

    -   [Change
        Password](/runestone/default/user/change_password){#passwordlink}

    -   [Register](/runestone/default/user/register){#registerlink}

    -   [Login](#)

    -   ::: {.slider .round}
        :::

        Dark Mode
-   
-   [[*[Scratch Activecode]{.visuallyhidden
    aria-label="Scratch Activecode"}*](javascript:runestoneComponents.popupScratchAC())]{#scratch_ac_link}
-   
-   [*[Help]{.visuallyhidden aria-label="Help"}*](#){.dropdown-toggle}
    -   [FAQ](http://runestoneinteractive.org/pages/faq.html)
    -   [Instructors Guide](https://guide.runestone.academy)
    -   
    -   [About Runestone](http://runestoneinteractive.org)
    -   [Report A
        Problem](/runestone/default/reportabug?course=fopp&page=Glossary)
-   

```{=html}
<!-- -->
```
-   
-   [This Chapter](../index.html){.dropdown-toggle}
    -   [4.1 Introduction to Python
        Modules](intro-PythonModules.html){.reference .internal}
    -   [4.2 Modules](intro-ModulesandGettingHelp.html){.reference
        .internal}
    -   [4.3 The random module](Therandommodule.html){.reference
        .internal}
    -   [4.4 Glossary](Glossary.html){.reference .internal}
    -   [4.5 Exercises](Exercises.html){.reference .internal}
-   
-   
:::
:::
:::

::: {#continue-reading .container}
:::

::: {#main-content .container role="main"}
::: {#glossary .section}
[4.4. ]{.section-number}Glossary[¶](#glossary "Permalink to this heading"){.headerlink}
=======================================================================================

deterministic[¶](#term-deterministic "Permalink to this term"){.headerlink}

:   A process that is repeatable and predictable.

documentation[¶](#term-documentation "Permalink to this term"){.headerlink}

:   A place where you can go to get detailed information about aspects
    of your programming language.

module[¶](#term-module "Permalink to this term"){.headerlink}

:   A file containing Python definitions and statements intended for use
    in other Python programs. The contents of a module are made
    available to the other program by using the *import* statement.

namespace[¶](#term-namespace "Permalink to this term"){.headerlink}

:   A naming system for making names unique, to avoid duplication and
    confusion. Within a namespace, no two names can be the same.

pseudo-random number[¶](#term-pseudo-random-number "Permalink to this term"){.headerlink}

:   A number that is not genuinely random but is instead created
    algorithmically.

random number[¶](#term-random-number "Permalink to this term"){.headerlink}

:   A number that is generated in such a way as to exhibit statistical
    randomness.

random number generator[¶](#term-random-number-generator "Permalink to this term"){.headerlink}

:   A function that will provide you with random numbers, usually
    between 0 and 1.

standard library[¶](#term-standard-library "Permalink to this term"){.headerlink}

:   A collection of modules that are part of the normal installation of
    Python.
:::

::: {style="width: 100%"}
::: {ea-publisher="runestoneacademy" ea-type="image" style="display: flex; justify-content: center"}
:::
:::

::: {#scprogresscontainer}
You have attempted []{#scprogresstotal} of []{#scprogressposs}
activities on this page

::: {#subchapterprogress aria-label="Page progress"}
:::
:::

-   [[](Therandommodule.html)]{#relations-prev}
-   [[](Exercises.html)]{#relations-next}
:::

::: {.container}
[]{#numuserspan}[]{.loggedinuser} \| [Back to top](#)

© Copyright 2017 bradleymiller. Created using
[Runestone](http://runestoneinteractive.org/) 7.2.10.
:::
